@@ -313,4 +313,4 @@ class CategoryContainerObj(object):
             object_provides=ICategoryContainer.__identifier__,
         )
         if len(container) == 1:
-            return container[0]
+            return container[0].getObject()
